from lambdatest_sdk_utils import is_smartui_enabled,fetch_dom_serializer,post_snapshot
from lambdatest_sdk_utils import get_pkg_name,setup_logger,get_logger


def smartui_snapshot(driver, name,**kwargs):
    # setting up logger
    setup_logger()
    logger = get_logger()
    
    try:
        if not name:
            raise Exception('The `snapshotName` argument is required.')
        if is_smartui_enabled() is False: 
            raise Exception("SmartUI server is not running.")
        
        resp = fetch_dom_serializer()
        driver.execute_script(resp['data']['dom'])

        # Serialize and capture the DOM
        dom = driver.execute_script("return {'dom':SmartUIDOM.serialize()}")

        # Post the dom to smartui endpoint
        post_snapshot(dom,name,get_pkg_name())

        logger.info(f'Snapshot captured {name}')
    except Exception as e:
        logger.error(f'Could not take snapshot "{name}" Error {e}')


from setuptools import setup, find_packages
from os import path

cwd = path.abspath(path.dirname(__file__))
with open(path.join(cwd, 'readme.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name="lambdatest-selenium-driver",
    version="1.0.0",
    author="LambdaTest <keys@lambdatest.com>",
    description="Python Selenium SDK for testing with Smart UI",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/LambdaTest/lambdatest-python-sdk",
    keywords="lambdatest python selenium sdk",
    packages=find_packages(),
    license="MIT",
    install_requires=[
        "selenium>=3",
        "lambdatest-sdk-utils==1.*"
    ],
    python_requires='>=3.6',
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 3",
        "Natural Language :: English",
        "License :: OSI Approved :: MIT License",
    ],
)
